@@ -47,7 +47,10 @@ from black import (
     parse_pyproject_toml,
     re_compile_maybe_verbose,
 )
-from black.const import DEFAULT_EXCLUDES, DEFAULT_INCLUDES
+from black.const import (  # pylint: disable=no-name-in-module
+    DEFAULT_EXCLUDES,
+    DEFAULT_INCLUDES,
+)
 from black.files import gen_python_files
 from black.report import Report
 
@@ -104,14 +107,14 @@ def read_black_config(src: Tuple[str, ...], value: Optional[str]) -> BlackConfig
     raw_config = parse_pyproject_toml(value)
 
     config: BlackConfig = {}
-    for key in {
+    for key in [
         "line_length",
         "skip_magic_trailing_comma",
         "skip_string_normalization",
-    }:
+    ]:
         if key in raw_config:
             config[key] = raw_config[key]  # type: ignore
-    for key in {"exclude", "extend_exclude", "force_exclude"}:
+    for key in ["exclude", "extend_exclude", "force_exclude"]:
         if key in raw_config:
             config[key] = re_compile_maybe_verbose(raw_config[key])  # type: ignore
     return config
@@ -135,6 +138,10 @@ def filter_python_files(
     sig = inspect.signature(gen_python_files)
     # those two exist and are required in black>=21.7b1.dev9
     kwargs = dict(verbose=False, quiet=False) if "verbose" in sig.parameters else {}
+    # `gitignore=` was replaced with `gitignore_dict=` in black==22.10.1.dev19+gffaaf48
+    for param in sig.parameters:
+        if param.startswith("gitignore"):
+            kwargs[param] = None  # type: ignore[assignment]
     absolute_paths = {p.resolve() for p in paths}
     directories = {p for p in absolute_paths if p.is_dir()}
     files = {p for p in absolute_paths if p not in directories}
@@ -147,7 +154,6 @@ def filter_python_files(
             extend_exclude=black_config.get("extend_exclude"),
             force_exclude=black_config.get("force_exclude"),
             report=Report(),
-            gitignore=None,
             **kwargs,
         )
     )
